==> pdk-0.22.5-sources.jar: software/aws/pdk/type_safe_api/MockResponseDataGenerationOptions.java <==
package software.aws.pdk.type_safe_api;

/**
 * Options for generating mock data.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.88.0 (build eaabd08)", date = "2023-09-20T01:23:03.577Z")
@software.amazon.jsii.Jsii(module = software.aws.pdk.$Module.class, fqn = "@aws/pdk.type_safe_api.MockResponseDataGenerationOptions")
@software.amazon.jsii.Jsii.Proxy(MockResponseDataGenerationOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MockResponseDataGenerationOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Set to true to disable generating mock data.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getDisable() {
        return null;
    }

    /**
     * Locale of generated data.
     * <p>
     * Default: en
     * <p>
     * @see <a href="https://fakerjs.dev/guide/localization.html#available-locales">https://fakerjs.dev/guide/localization.html#available-locales</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLocale() {
        return null;
    }

    /**
     * Maximum length of generated arrays.
     * <p>
     * Default: 3
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getMaxArrayLength() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MockResponseDataGenerationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MockResponseDataGenerationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MockResponseDataGenerationOptions> {
        java.lang.Boolean disable;
        java.lang.String locale;
        java.lang.Number maxArrayLength;

        /**
         * Sets the value of {@link MockResponseDataGenerationOptions#getDisable}
         * @param disable Set to true to disable generating mock data.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder disable(java.lang.Boolean disable) {
            this.disable = disable;
            return this;
        }

        /**
         * Sets the value of {@link MockResponseDataGenerationOptions#getLocale}
         * @param locale Locale of generated data.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder locale(java.lang.String locale) {
            this.locale = locale;
            return this;
        }

        /**
         * Sets the value of {@link MockResponseDataGenerationOptions#getMaxArrayLength}
         * @param maxArrayLength Maximum length of generated arrays.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maxArrayLength(java.lang.Number maxArrayLength) {
            this.maxArrayLength = maxArrayLength;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MockResponseDataGenerationOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MockResponseDataGenerationOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MockResponseDataGenerationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MockResponseDataGenerationOptions {
        private final java.lang.Boolean disable;
        private final java.lang.String locale;
        private final java.lang.Number maxArrayLength;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.disable = software.amazon.jsii.Kernel.get(this, "disable", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.locale = software.amazon.jsii.Kernel.get(this, "locale", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.maxArrayLength = software.amazon.jsii.Kernel.get(this, "maxArrayLength", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.disable = builder.disable;
            this.locale = builder.locale;
            this.maxArrayLength = builder.maxArrayLength;
        }

        @Override
        public final java.lang.Boolean getDisable() {
            return this.disable;
        }

        @Override
        public final java.lang.String getLocale() {
            return this.locale;
        }

        @Override
        public final java.lang.Number getMaxArrayLength() {
            return this.maxArrayLength;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDisable() != null) {
                data.set("disable", om.valueToTree(this.getDisable()));
            }
            if (this.getLocale() != null) {
                data.set("locale", om.valueToTree(this.getLocale()));
            }
            if (this.getMaxArrayLength() != null) {
                data.set("maxArrayLength", om.valueToTree(this.getMaxArrayLength()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws/pdk.type_safe_api.MockResponseDataGenerationOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MockResponseDataGenerationOptions.Jsii$Proxy that = (MockResponseDataGenerationOptions.Jsii$Proxy) o;

            if (this.disable != null ? !this.disable.equals(that.disable) : that.disable != null) return false;
            if (this.locale != null ? !this.locale.equals(that.locale) : that.locale != null) return false;
            return this.maxArrayLength != null ? this.maxArrayLength.equals(that.maxArrayLength) : that.maxArrayLength == null;
        }

        @Override
        public final int hashCode() {
            int result = this.disable != null ? this.disable.hashCode() : 0;
            result = 31 * result + (this.locale != null ? this.locale.hashCode() : 0);
            result = 31 * result + (this.maxArrayLength != null ? this.maxArrayLength.hashCode() : 0);
            return result;
        }
    }
}

==> pdk-0.22.16-sources.jar: software/aws/pdk/type_safe_api/MockResponseDataGenerationOptions.java <==
package software.aws.pdk.type_safe_api;

/**
 * Options for generating mock data.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.88.0 (build eaabd08)", date = "2023-10-16T23:32:42.450Z")
@software.amazon.jsii.Jsii(module = software.aws.pdk.$Module.class, fqn = "@aws/pdk.type_safe_api.MockResponseDataGenerationOptions")
@software.amazon.jsii.Jsii.Proxy(MockResponseDataGenerationOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MockResponseDataGenerationOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Set to true to disable generating mock data.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getDisable() {
        return null;
    }

    /**
     * Locale of generated data.
     * <p>
     * Default: en
     * <p>
     * @see <a href="https://fakerjs.dev/guide/localization.html#available-locales">https://fakerjs.dev/guide/localization.html#available-locales</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLocale() {
        return null;
    }

    /**
     * Maximum length of generated arrays.
     * <p>
     * Default: 3
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getMaxArrayLength() {
        return null;
    }

    /**
     * Seed for faker to generate data with.
     * <p>
     * Default: 1337
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getSeed() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MockResponseDataGenerationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MockResponseDataGenerationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MockResponseDataGenerationOptions> {
        java.lang.Boolean disable;
        java.lang.String locale;
        java.lang.Number maxArrayLength;
        java.lang.Number seed;

        /**
         * Sets the value of {@link MockResponseDataGenerationOptions#getDisable}
         * @param disable Set to true to disable generating mock data.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder disable(java.lang.Boolean disable) {
            this.disable = disable;
            return this;
        }

        /**
         * Sets the value of {@link MockResponseDataGenerationOptions#getLocale}
         * @param locale Locale of generated data.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder locale(java.lang.String locale) {
            this.locale = locale;
            return this;
        }

        /**
         * Sets the value of {@link MockResponseDataGenerationOptions#getMaxArrayLength}
         * @param maxArrayLength Maximum length of generated arrays.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maxArrayLength(java.lang.Number maxArrayLength) {
            this.maxArrayLength = maxArrayLength;
            return this;
        }

        /**
         * Sets the value of {@link MockResponseDataGenerationOptions#getSeed}
         * @param seed Seed for faker to generate data with.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder seed(java.lang.Number seed) {
            this.seed = seed;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MockResponseDataGenerationOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MockResponseDataGenerationOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MockResponseDataGenerationOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MockResponseDataGenerationOptions {
        private final java.lang.Boolean disable;
        private final java.lang.String locale;
        private final java.lang.Number maxArrayLength;
        private final java.lang.Number seed;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.disable = software.amazon.jsii.Kernel.get(this, "disable", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.locale = software.amazon.jsii.Kernel.get(this, "locale", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.maxArrayLength = software.amazon.jsii.Kernel.get(this, "maxArrayLength", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.seed = software.amazon.jsii.Kernel.get(this, "seed", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.disable = builder.disable;
            this.locale = builder.locale;
            this.maxArrayLength = builder.maxArrayLength;
            this.seed = builder.seed;
        }

        @Override
        public final java.lang.Boolean getDisable() {
            return this.disable;
        }

        @Override
        public final java.lang.String getLocale() {
            return this.locale;
        }

        @Override
        public final java.lang.Number getMaxArrayLength() {
            return this.maxArrayLength;
        }

        @Override
        public final java.lang.Number getSeed() {
            return this.seed;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDisable() != null) {
                data.set("disable", om.valueToTree(this.getDisable()));
            }
            if (this.getLocale() != null) {
                data.set("locale", om.valueToTree(this.getLocale()));
            }
            if (this.getMaxArrayLength() != null) {
                data.set("maxArrayLength", om.valueToTree(this.getMaxArrayLength()));
            }
            if (this.getSeed() != null) {
                data.set("seed", om.valueToTree(this.getSeed()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws/pdk.type_safe_api.MockResponseDataGenerationOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MockResponseDataGenerationOptions.Jsii$Proxy that = (MockResponseDataGenerationOptions.Jsii$Proxy) o;

            if (this.disable != null ? !this.disable.equals(that.disable) : that.disable != null) return false;
            if (this.locale != null ? !this.locale.equals(that.locale) : that.locale != null) return false;
            if (this.maxArrayLength != null ? !this.maxArrayLength.equals(that.maxArrayLength) : that.maxArrayLength != null) return false;
            return this.seed != null ? this.seed.equals(that.seed) : that.seed == null;
        }

        @Override
        public final int hashCode() {
            int result = this.disable != null ? this.disable.hashCode() : 0;
            result = 31 * result + (this.locale != null ? this.locale.hashCode() : 0);
            result = 31 * result + (this.maxArrayLength != null ? this.maxArrayLength.hashCode() : 0);
            result = 31 * result + (this.seed != null ? this.seed.hashCode() : 0);
            return result;
        }
    }
}
